powered by
Function is necessary for eatRep and eatModel as well and therefore exported to namespace.
eatRep
eatModel
existsBackgroundVariables (dat, variable, warnIfMissing = FALSE, stopIfMissingOnVars = NULL)
a structured list of variable names
A data frame
vector of column number(s) or variable name(s)
Logical: gives a warning if the variable contains missing values
Character vector of variable names. Only for these variables, warnings as raised through warnIfMissing = TRUE are turned into errors.
warnIfMissing = TRUE
# for more detailed examples, see help page of checkBackgroundVariables data(mtcars) existsBackgroundVariables(mtcars, 2:4)
Run the code above in your browser using DataLab